==> neo4j-ogm-core-3.1.7-sources.jar: org/neo4j/ogm/context/DirectedRelationshipForType.java <==
/*
 * Copyright (c) 2002-2019 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.ogm.context;

/**
 * A DirectedRelationship mapping to objects of a particular type.
 *
 * @author Luanne Misquitta
 */
public class DirectedRelationshipForType extends DirectedRelationship {

    Class type;

    public DirectedRelationshipForType(String relationshipType, String relationshipDirection, Class type) {
        super(relationshipType, relationshipDirection);
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        if (!super.equals(o))
            return false;

        DirectedRelationshipForType that = (DirectedRelationshipForType) o;

        return type.equals(that.type);
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + type.hashCode();
        return result;
    }
}

==> neo4j-ogm-core-3.2.16-sources.jar: org/neo4j/ogm/context/DirectedRelationshipForType.java <==
/*
 * Copyright (c) 2002-2020 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.ogm.context;

/**
 * A DirectedRelationship mapping to objects of a particular type.
 *
 * @author Luanne Misquitta
 */
public class DirectedRelationshipForType extends DirectedRelationship {

    Class type;

    public DirectedRelationshipForType(String relationshipType, String relationshipDirection, Class type) {
        super(relationshipType, relationshipDirection);
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        if (!super.equals(o)) {
            return false;
        }

        DirectedRelationshipForType that = (DirectedRelationshipForType) o;

        return type.equals(that.type);
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + type.hashCode();
        return result;
    }
}
